/**
  * @file remoteControl.ino
  * @author Jan Bělohoubek
  * 
  * @brief Komplexnější příklad pro ovládání periferií 
  * přes a IoT síť LoRaWAN
  * 
  * Podrobnější dokumentace:
  * https://edu.ketcube.cz/pages/example_remoteControl.html
  * 
  * Copyright (c) 2020 University of West Bohemia in Pilsen
  * All rights reserved.
  *
  * Developed by:
  * The SmartCampus Team
  * Department of Materials and Technology
  * www.smartcampus.cz | www.zcu.cz
  * 
  * See the License: 
  * https://edu.ketcube.cz/LICENSE.md
  * 
  */

void onNewData(byte * buffer, byte len) {
  byte i;

  // Dekódování příkazu pro LED
  if (len > 0) {
    if (buffer[0] == 1) {
      KETCube.LED.set(LED1, LED_BLINK_SINGLE);
      KETCube.Terminal.print("LED1");
    } else if (buffer[0] == 2) {
      KETCube.LED.set(LED2, LED_BLINK_SINGLE);
      KETCube.Terminal.print("LED2");
    } else if (buffer[0] == 3) {
      KETCube.LED.set(LED1, LED_BLINK_SINGLE);
      KETCube.LED.set(LED2, LED_BLINK_SINGLE);
      KETCube.Terminal.print("LED1+LED2");
    }
  }

  // Nastavení přehrání zadaných tónů
  for (i = 1; i < len; i++) {
    // tóny jsou přijaty v jednotkách kHz
    // každý ton bude znít 300 ms,
    // následovat bude pauza 1000ms
    KETCube.PWM.tone(buffer[i] * 1000, 300, 1000);
    KETCube.Terminal.print("Play: %d kHz", buffer[i]);
  }
}

void setup() {
  // Zobrazení zprávy v terminálu na začátku inicializace
  KETCube.Terminal.print("RemoteControl @ KETCube");

  // Nastavení LED1 a LED2
  KETCube.LED.init(LED1, HIGH);
  KETCube.LED.init(LED2, HIGH);
  KETCube.LED.set(LED1, LED_OFF);
  KETCube.LED.set(LED2, LED_OFF);

  // Inicializace PWM - PIN PWM
  KETCube.PWM.init();

  // Iniciallizace zpracování přijatých dat
  KETCube.LPWAN.regOnRxHandler(&onNewData);
}

void loop() {
  // žádný periodický kód
}
