/**
  * @file temperatureSensor.ino
  * @author Jan Bělohoubek
  * 
  * @brief Příklad pro seznámení se 
  * s jednoduchým senzorem a IoT sítí LoRaWAN
  * 
  * Čtení hodnoty napětí na výstupu teplotního senzoru 
  * a její odeslání do sítě LoRaWAN.
  * 
  * Podrobnější dokumentace:
  * https://edu.ketcube.cz/pages/example_temperatureSensor.html
  * 
  * Copyright (c) 2020 University of West Bohemia in Pilsen
  * All rights reserved.
  *
  * Developed by:
  * The SmartCampus Team
  * Department of Materials and Technology
  * www.smartcampus.cz | www.zcu.cz
  * 
  * See the License: 
  * https://edu.ketcube.cz/LICENSE.md
  * 
  */

#define SENSOR_OFFSET  500 // Offset je 500mV
#define SENSOR_SCALING  10 // Rozlišení je 10mV/C

uint8_t buffer[2]; // pole pro předání hodnot modulu LoRa

void setup() {
  // Zobrazení zprávy v terminálu na začátku inicializace
  KETCube.Terminal.print("TempSensor @ KETCube");

  // Nastaví PIN AN jako analogový vstup
  KETCube.IO.pinMode(AN, ANALOG);

  // Inicializuje ADC
  KETCube.Analog.init();
}

void loop() {
  uint16_t mv;
  int16_t temp;
  
  // Měření hodnoty napětí na výstupu senzoru
  mv = KETCube.Analog.read(AN);
  
  // Výpis hodnoty napětí
  KETCube.Terminal.print("U = %d mV", mv);

  // Přepočet hodnoty napětí na teplotu
  temp = (((int16_t) mv) - SENSOR_OFFSET) / SENSOR_SCALING;

  // Výpis naměřené teploty
  KETCube.Terminal.print("T = %d C", temp);

  // Odeslání dat do sítě LoRaWAN
  buffer[0] = (byte) ((temp >> 8) & 0xFF);
  buffer[1] = (byte) (temp & 0xFF);
  KETCube.LPWAN.send(buffer, 2);
}
